Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4)

Unified Diff: editor/tools/plugins/com.google.dart.server/src/com/google/dart/server/generated/types/ExecutionService.java

Issue 546073006: Update RemoteAnalysisServerImpl and tests to fix the build. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.server/src/com/google/dart/server/generated/types/ExecutionService.java
diff --git a/editor/tools/plugins/com.google.dart.server/src/com/google/dart/server/generated/types/ServerService.java b/editor/tools/plugins/com.google.dart.server/src/com/google/dart/server/generated/types/ExecutionService.java
similarity index 84%
copy from editor/tools/plugins/com.google.dart.server/src/com/google/dart/server/generated/types/ServerService.java
copy to editor/tools/plugins/com.google.dart.server/src/com/google/dart/server/generated/types/ExecutionService.java
index 014ddc475bc6244bde897565a9fbfc4248a59382..41dbdb411543c4014d7ec1ba3867cd31de250de6 100644
--- a/editor/tools/plugins/com.google.dart.server/src/com/google/dart/server/generated/types/ServerService.java
+++ b/editor/tools/plugins/com.google.dart.server/src/com/google/dart/server/generated/types/ExecutionService.java
@@ -17,12 +17,12 @@
package com.google.dart.server.generated.types;
/**
* An enumeration of the services provided by the server domain.
*
* @coverage dart.server.generated.types
*/
-public class ServerService {
+public class ExecutionService {
- public static final String STATUS = "STATUS";
+ public static final String LAUNCH_DATA = "LAUNCH_DATA";
}

Powered by Google App Engine
@@ -17,12 +17,12 @@
package com.google.dart.server.generated.types;
/**
- * An enumeration of the services provided by the server domain.
+ * An enumeration of the services provided by the execution domain.
*
* @coverage dart.server.generated.types
This is Rietveld 408576698